@@ -1,67 +1,31 @@
 package PerlX::Maybe;
 
-use 5.006;
+use 5.008;
 use strict;
 
+our (@EXPORT, @ISA);
 BEGIN {
 	$PerlX::Maybe::AUTHORITY = 'cpan:TOBYINK';
-	$PerlX::Maybe::VERSION   = '0.999_02';
+	$PerlX::Maybe::VERSION   = '0.001';
 	
 	require Exporter;
-	our @ISA         = qw/ Exporter /;
-	our @EXPORT      = qw/ maybe /;
-	our @EXPORT_OK   = qw/ maybe provided /;
-	our %EXPORT_TAGS = (all => \@EXPORT_OK, default => \@EXPORT);
+	@ISA       = qw/Exporter/;
+	@EXPORT    = qw/maybe/;
 }
 
-unless (($ENV{PERLX_MAYBE_IMPLEMENTATION}||'') =~ /pp/i)
-{
-	eval q{ use PerlX::Maybe::XS 0.003 ':all' };
-}
-
-__PACKAGE__->can('maybe') ? eval <<'END_XS' : eval <<'END_PP';
-
-sub IMPLEMENTATION () { "XS" }
-
-END_XS
-
-sub IMPLEMENTATION () { "PP" }
-
 sub maybe ($$@)
 {
-	if (defined $_[0] and defined $_[1])
-	{
-		@_
-	}
-	else
-	{
-		(scalar @_ > 1) ? @_[2 .. $#_] : qw()
-	}
+	my ($x, $y, @rest) = @_;
+	my @r = (
+		(defined $y && defined $x ? ($x, $y) : ()),
+		@rest,
+		);
+	return @r;
 }
 
-sub provided ($$$@)
-{
-	if (shift)
-	{
-		@_
-	}
-	else
-	{
-		(scalar @_ > 1) ? @_[2 .. $#_] : qw()
-	}
-}
-
-END_PP
-
 __FILE__
 __END__
 
-=pod
-
-=encoding utf8
-
-=for stopwords benchmarking
-
 =head1 NAME
 
 PerlX::Maybe - return a pair only if they are both defined
@@ -73,14 +37,14 @@ You once wrote:
  my $bob = Person->new(
     defined $name ? (name => $name) : (),
     defined $age ? (age => $age) : (),
- );
+    );
 
 Now you can write:
 
  my $bob = Person->new(
     maybe name => $name,
     maybe age  => $age,
- );
+    );
 
 =head1 DESCRIPTION
 
@@ -91,7 +55,7 @@ arguments like this:
  my $bob = Person->new(
     name => $name,
     age => $age,
- );
+    );
 
 Will result in the C<name> and C<age> attributes possibly being set to
 undef (if the corresponding C<$name> and C<$age> variables are not defined),
@@ -107,22 +71,11 @@ at all when they are undefined, ugly looking code like this is often used:
  my $bob = Person->new(
     defined $name ? (name => $name) : (),
     defined $age ? (age => $age) : (),
- );
+    );
 
-or:
+A slightly more elegant solution is the C<maybe> function:
 
- my $bob = Person->new(
-    (name => $name) x!!(defined $name),
-    (age  => $age)  x!!(defined $age),
- );
-
-A slightly more elegant solution is the C<maybe> function.
-
-=head2 Functions
-
-=over
-
-=item C<< maybe $x => $y, @rest >>
+=head2 C<< maybe $x => $y, @rest >>
 
 This function checks that C<< $x >> and C<< $y >> are both defined. If they
 are, it returns them both as a list; otherwise it returns the empty list.
@@ -139,41 +92,10 @@ to "just work".
    maybe phone     => $tel,
    maybe email     => $email,
          unique_id => $id,
- );
+   );
 
 This function is exported by default.
 
-=item C<< provided $condition, $x => $y, @rest >>
-
-Like C<maybe> but allows you to use a custom condition expression:
-
- my $bob = Person->new(
-                             name      => $name,
-                             address   => $addr,
-   provided length($tel),    phone     => $tel,
-   provided $email =~ /\@/,  email     => $email,
-                             unique_id => $id,
- );
-
-This function is not exported by default.
-
-=item C<< PerlX::Maybe::IMPLEMENTATION >>
-
-Indicates whether the XS backend L<PerlX::Maybe::XS> was loaded.
-
-=back
-
-=head2 XS Backend
-
-If you install L<PerlX::Maybe::XS>, a faster XS-based implementation will
-be used instead of the pure Perl functions. My basic benchmarking experiments
-seem to show this to be around 30% faster.
-
-=head2 Environment
-
-The environment variable C<PERLX_MAYBE_IMPLEMENTATION> may be set to
-C<< "PP" >> to prevent the XS backend from loading.
-
 =head1 BUGS
 
 Please report any bugs to
@@ -181,7 +103,7 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=PerlX-Maybe>.
 
 =head1 SEE ALSO
 
-L<Syntax::Feature::Maybe>, L<PerlX::Maybe::XS>.
+L<Syntax::Feature::Maybe>.
 
 L<MooseX::UndefTolerant>, L<PerlX::Perform>, L<Exporter>.
 
@@ -191,7 +113,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012-2013 by Toby Inkster.
+This software is copyright (c) 2012 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
