@@ -1,18 +1,18 @@
 package Syntax::Feature::Maybe;
 
-use 5.006;
+use 5.008;
 use strict;
 use PerlX::Maybe qw//;
 
 BEGIN {
 	$Syntax::Feature::Maybe::AUTHORITY = 'cpan:TOBYINK';
-	$Syntax::Feature::Maybe::VERSION   = '0.999_02';
+	$Syntax::Feature::Maybe::VERSION   = '0.001';
 }
 
 sub install
-{
+{	
 	my ($class, %args) = @_;
-	my $into = delete($args{into});
+	my $into = delete $args{into};
 	
 	foreach my $f (qw/maybe/)
 	{
@@ -24,10 +24,6 @@ sub install
 __FILE__
 __END__
 
-=pod
-
-=encoding utf8
-
 =head1 NAME
 
 Syntax::Feature::Maybe - use syntax qw/maybe/
@@ -51,7 +47,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012-2013 by Toby Inkster.
+This software is copyright (c) 2012 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
